### Name: srLSE
### Title: Compute the LSE of a convex hazard with fixed antimode
### Aliases: srLSE
### Keywords: nonparametric survival iteration optimize

### ** Examples

# Generate sample data:
set.seed(1111, kind="default")
x       <- rweibull(50, 3) 

# Find the LSE with antimode a=0 over the range [0,1]:
TT      <- 1    
lse     <- srLSE(x, a=0, TT=TT)

# plot the true hazard function and the lse
h.true  <- function(x) 3*x^2
tt      <- c(0,sort(lse$lse$supp$tau), sort(lse$lse$supp$eta), TT)
yy      <- sapply(tt, h, supp=lse$lse$supp, hpar=lse$lse$mix)

plot(h.true, xlim=c(0,TT), lwd=2, col="blue", ylab="hazard", xlab="time", main="LSE (a=0)")
lines(tt,yy, lwd=2, col="red")
legend("topleft", c("true","estimated"),col=c("blue", "red"), lwd=2, inset = .05)



